<?php
// -----------------------------------------------------------------------
//
// $Id: articles.php 157 2012-03-26 15:20:43Z raoul $
//
// Copyright (C) 2003-2012 Raoul Proena
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.fr/
//
// -----------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// -----------------------------------------------------------------------

include('./../includes/common.php');

page_header($lang['ADMIN_ARTICLES_TITLE']);

// Advanced moderator or administrator ?
if ($users['user_level'] > 2)
{
    // Add (or preview) ?
    if (isset($_POST['add_article']) || isset($_POST['preview_article']))
    {
        $error = '';
        if (!trim($_POST['article_subject']))
        {
            $error .= $lang['NO_ARTICLE_SUBJECT'];
        }
        if (!trim($_POST['article_text']))
        {
            $error .= $lang['NO_ARTICLE_TEXT'];
        }
        if ($error)
        {
            error_template($error);
        }
        else
        {
            $article_subject = chars2entities($_POST['article_subject'], ENT_QUOTES);
            if ($settings['allow_html'] == 0)
            {
                $article_text = chars2entities($_POST['article_text'], ENT_QUOTES);
            }
            else
            {
                $article_text = do_html($_POST['article_text']);
            }
            $temp = $article_text;
            $article_text = make_clickable($article_text);
            $article_text = do_bbcodes($article_text);
            if ($settings['allow_smilies'] != 0)
            {
                $article_text = do_smilies($article_text);
            }
            // Preview form
            if (isset($_POST['preview_article']))
            {
                $date_format = get_date_format();
                $date_offset = get_date_offset();
                $article_date = date($date_format, (time() + $date_offset));
                // Article (HTML)
                $article_subject = stripslashes($article_subject);
                $article_text = stripslashes($article_text);
                $article_text = undo_escape_sequences($article_text);
                // Form
                $article_text2 = stripslashes($temp);
                if ($settings['allow_html'] == 0)
                {
                    $html_support = $lang['HTML_DISABLED'];
                }
                else
                {
                    $html_support = $lang['HTML_ENABLED'];
                }
                $template->set_file('admin', 'admin/articles/preview.htpl');
                $template->set_var(array('ADD' => $lang['ADD'],
                                         'ADMIN_ARTICLES_HEADER1' => $lang['ADMIN_ARTICLES_HEADER1'],
                                         'ADMIN_ARTICLES_RELEASE' => sprintf($lang['ADMIN_ARTICLES_RELEASE'], $_SESSION['user_id'], $users['user_name'], $article_date),
                                         'ARTICLE_SUBJECT' => $article_subject,
                                         'ARTICLE_TEXT' => $article_text,
                                         'ARTICLE_TEXT2' => $article_text2,
                                         'BACK_ADMIN_INDEX' => $lang['BACK_ADMIN_INDEX'],
                                         'BACK_HOME' => $lang['BACK_HOME'],
                                         'FORM_ARTICLE_SUBJECT' => $lang['FORM_ARTICLE_SUBJECT'],
                                         'FORM_ARTICLE_TEXT' => $lang['FORM_ARTICLE_TEXT'],
                                         'HTML_SUPPORT' => $html_support,
                                         'PREVIEW' => $lang['PREVIEW'],
                                         'SMILIES_LIST' => get_smilies_list(0)));
                $template->parse('admin');
            }
            // Add form
            else
            {
                $sql->query('INSERT INTO ' . TABLE_ARTICLES . ' (user_id, article_subject, article_text, article_date)
                             VALUES (\'' . $_SESSION['user_id'] . '\', \'' . $article_subject . '\', \'' . $article_text . '\', \'' . time() . '\')');
                make_articles_rss();
                success_template($lang['ADMIN_ARTICLES_ADDED'], './../admin/index.php');
            }
        }
    }
    // Articles list
    elseif (isset($_GET['action']) && $_GET['action'] == 'view_articles')
    {
        // Create pages list
        if (empty($_GET['page']))
        {
            $_GET['page'] = 1;
        }
        $articles_per_page = $settings['articles_per_page'];
        $articles_offset = ($_GET['page'] - 1) * $articles_per_page;
        $sql->query('SELECT article_id
                     FROM ' . TABLE_ARTICLES);
        $num_articles = $sql->num_rows();
        $num_pages = ceil($num_articles / $articles_per_page);
        $pages_list = get_pages_list('./../admin/articles.php?action=view_articles&amp;', $num_pages);

        $date_format = get_date_format();
        $date_offset = get_date_offset();
        $template->set_file('admin', 'admin/articles/view.htpl');
        $template->set_block('admin', 'ARTICLES_BLOCK', 'articles');
        $sql->query('SELECT ' . TABLE_ARTICLES . '.article_date, ' . TABLE_ARTICLES . '.article_id, ' . TABLE_ARTICLES . '.article_subject, ' . TABLE_USERS . '.user_id, ' . TABLE_USERS . '.user_name
                     FROM ' . TABLE_ARTICLES . ', ' . TABLE_USERS . '
                     WHERE ' . TABLE_ARTICLES . '.user_id = ' . TABLE_USERS . '.user_id
                     ORDER BY ' . TABLE_ARTICLES . '.article_date DESC
                     LIMIT ' . $articles_offset . ', ' . $articles_per_page);
        while ($table_articles = $sql->fetch())
        {
            $article_date = date($date_format, ($table_articles['article_date'] + $date_offset));
            $template->set_var(array('ARTICLE_ID' => $table_articles['article_id'],
                                     'ARTICLE_RELEASE' => sprintf($lang['ADMIN_ARTICLES_RELEASE'], $table_articles['user_id'], $table_articles['user_name'], $article_date),
                                     'ARTICLE_SUBJECT' => $table_articles['article_subject'],
                                     'DELETE' => $lang['DELETE'],
                                     'EDIT' => $lang['EDIT']));
            $template->parse('ARTICLES_BLOCK', 'articles', true);
        }
        $template->set_var(array('ADMIN_ARTICLES_HEADER2' => $lang['ADMIN_ARTICLES_HEADER2'],
                                 'ADMIN_ARTICLES_PAGES' => sprintf($lang['ADMIN_ARTICLES_PAGES'], $pages_list),
                                 'BACK_ADMIN_INDEX' => $lang['BACK_ADMIN_INDEX']));
        $template->parse('admin');
    }
    // Edit form
    elseif (isset($_GET['action']) && $_GET['action'] == 'edit_article')
    {
        if (!empty($_GET['article_id']))
        {
            $sql->query('SELECT article_subject, article_text
                         FROM ' . TABLE_ARTICLES . '
                         WHERE article_id = \'' . $_GET['article_id'] . '\'');
            $table_articles = $sql->fetch();
            // Check article
            if (!$table_articles['article_subject'])
            {
                error_template($lang['ADMIN_QUERY_ERROR']);
            }
            else
            {
                if ($settings['allow_html'] == 0)
                {
                    $html_support = $lang['HTML_DISABLED'];
                }
                else
                {
                    $html_support = $lang['HTML_ENABLED'];
                }
                $article_text = undo_smilies($table_articles['article_text']);
                $article_text = undo_bbcodes($article_text);
                $template->set_file('admin', 'admin/articles/edit.htpl');
                $template->set_var(array('ADMIN_ARTICLES_HEADER1' => $lang['ADMIN_ARTICLES_HEADER1'],
                                         'ARTICLE_ID' => $_GET['article_id'],
                                         'ARTICLE_SUBJECT' => $table_articles['article_subject'],
                                         'ARTICLE_TEXT' => $article_text,
                                         'BACK_ADMIN_INDEX' => $lang['BACK_ADMIN_INDEX'],
                                         'EDIT' => $lang['EDIT'],
                                         'FORM_ARTICLE_SUBJECT' => $lang['FORM_ARTICLE_SUBJECT'],
                                         'FORM_ARTICLE_TEXT' => $lang['FORM_ARTICLE_TEXT'],
                                         'HTML_SUPPORT' => $html_support,
                                         'PREVIEW' => $lang['PREVIEW'],
                                         'SMILIES_LIST' => get_smilies_list(0)));
                $template->parse('admin');
            }
        }
        else
        {
            error_template($lang['ADMIN_QUERY_ERROR']);
        }
    }
    // Edit (or preview) ?
    elseif (isset($_POST['edit_article']) || isset($_POST['preview_edited_article']))
    {
        $error = '';
        if (!trim($_POST['article_subject']))
        {
            $error .= $lang['NO_ARTICLE_SUBJECT'];
        }
        if (!trim($_POST['article_text']))
        {
            $error .= $lang['NO_ARTICLE_TEXT'];
        }
        if ($error)
        {
            error_template($error);
        }
        else
        {
            $article_subject = chars2entities($_POST['article_subject'], ENT_QUOTES);
            if ($settings['allow_html'] == 0)
            {
                $article_text = chars2entities($_POST['article_text'], ENT_QUOTES);
            }
            else
            {
                $article_text = do_html($_POST['article_text']);
            }
            $temp = $article_text;
            $article_text = make_clickable($article_text);
            $article_text = do_bbcodes($article_text);
            if ($settings['allow_smilies'] != 0)
            {
                $article_text = do_smilies($article_text);
            }
            // Preview form
            if (isset($_POST['preview_edited_article']))
            {
                $date_format = get_date_format();
                $date_offset = get_date_offset();
                $article_date = date($date_format, (time() + $date_offset));
                // Article (HTML)
                $article_subject = stripslashes($article_subject);
                $article_text = stripslashes($article_text);
                $article_text = undo_escape_sequences($article_text);
                // Form
                $article_text2 = stripslashes($temp);
                if ($settings['allow_html'] == 0)
                {
                    $html_support = $lang['HTML_DISABLED'];
                }
                else
                {
                    $html_support = $lang['HTML_ENABLED'];
                }
                $template->set_file('admin', 'admin/articles/preview_edited.htpl');
                $template->set_var(array('ADMIN_ARTICLES_HEADER1' => $lang['ADMIN_ARTICLES_HEADER1'],
                                         'ADMIN_ARTICLES_RELEASE' => sprintf($lang['ADMIN_ARTICLES_RELEASE'], $_SESSION['user_id'], $users['user_name'], $article_date),
                                         'ARTICLE_ID' => $_POST['article_id'],
                                         'ARTICLE_SUBJECT' => $article_subject,
                                         'ARTICLE_TEXT' => $article_text,
                                         'ARTICLE_TEXT2' => $article_text2,
                                         'BACK_ADMIN_INDEX' => $lang['BACK_ADMIN_INDEX'],
                                         'BACK_HOME' => $lang['BACK_HOME'],
                                         'EDIT' => $lang['EDIT'],
                                         'FORM_ARTICLE_SUBJECT' => $lang['FORM_ARTICLE_SUBJECT'],
                                         'FORM_ARTICLE_TEXT' => $lang['FORM_ARTICLE_TEXT'],
                                         'HTML_SUPPORT' => $html_support,
                                         'PREVIEW' => $lang['PREVIEW'],
                                         'SMILIES_LIST' => get_smilies_list(0)));
                $template->parse('admin');
            }
            // Add form
            else
            {
                $sql->query('UPDATE ' . TABLE_ARTICLES . '
                             SET user_id = \'' . $_SESSION['user_id'] . '\', article_subject = \'' . $article_subject . '\', article_text = \'' . $article_text . '\', article_date = \'' . time() . '\'
                             WHERE article_id = \'' . $_POST['article_id'] . '\'');
                make_articles_rss();
                success_template($lang['ADMIN_ARTICLES_EDITED'], './../admin/index.php');
            }
        }
    }
    // Delete ?
    elseif (isset($_GET['action']) && $_GET['action'] == 'delete_article')
    {
        if (!empty($_GET['article_id']))
        {
            $sql->query('SELECT article_id
                         FROM ' . TABLE_ARTICLES . '
                         WHERE article_id = \'' . $_GET['article_id'] . '\'');
            $table_articles = $sql->fetch();
            // Check article
            if (!$table_articles['article_id'])
            {
                error_template($lang['ADMIN_QUERY_ERROR']);
            }
            else
            {
                $sql->query('DELETE FROM ' . TABLE_ARTICLES . '
                             WHERE article_id = \'' . $_GET['article_id'] . '\'');
                make_articles_rss();
                success_template($lang['ADMIN_ARTICLES_DELETED'], './../admin/index.php');
            }
        }
        else
        {
            error_template($lang['ADMIN_QUERY_ERROR']);
        }
    }
    // Add form
    else
    {
        if ($settings['allow_html'] == 0)
        {
            $html_support = $lang['HTML_DISABLED'];
        }
        else
        {
            $html_support = $lang['HTML_ENABLED'];
        }
        $template->set_file('admin', 'admin/articles/add.htpl');
        $template->set_var(array('ADD' => $lang['ADD'],
                                 'ADMIN_ARTICLES_HEADER1' => $lang['ADMIN_ARTICLES_HEADER1'],
                                 'BACK_ADMIN_INDEX' => $lang['BACK_ADMIN_INDEX'],
                                 'FORM_ARTICLE_SUBJECT' => $lang['FORM_ARTICLE_SUBJECT'],
                                 'FORM_ARTICLE_TEXT' => $lang['FORM_ARTICLE_TEXT'],
                                 'HTML_SUPPORT' => $html_support,
                                 'PREVIEW' => $lang['PREVIEW'],
                                 'SMILIES_LIST' => get_smilies_list(0)));
        $template->parse('admin');
    }
}
// Other
else
{
    error_template($lang['ADMIN_LEVEL_ERROR']);
}

page_footer();

?>