<?php
// -----------------------------------------------------------------------
//
// $Id: cache.php 146 2012-03-25 07:33:39Z raoul $
//
// Copyright (C) 2003-2012 Raoul Proena
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.fr/
//
// -----------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// -----------------------------------------------------------------------

class cache
{
    var $db = './../cache/cache.db';
    var $dir = './../cache';
    var $ext = '.cache';

    function check()
    {
        $file = $this->locate();

        if (file_exists($file))
        {
            $time = filemtime($file);
        }
        else
        {
            $time = 0;
        }

        $content = unserialize(file_get_contents($this->db));
        // Initial content of cache.db file: a:1:{s:0:"";a:2:{s:10:"expiration";i:0;s:8:"template";s:0:"";}}
        if (array_key_exists($file, $content))
        {
            // Cache file still valid?
            if ((time() - $content[$file]['expiration']) < $time)
            {
                // Modifications in template file?
                if ($time < filemtime($content[$file]['template']))
                {
                    $this->clean($file);
                }
                else
                {
                    readfile($file);
                    $GLOBALS['sql']->close();
                    session_write_close();
                    exit();
                }
            }
            else
            {
                $this->clean($file);
            }
        }
        return true;
    }

    function clean($file)
    {
        if (file_exists($file))
        {
            unlink($file);

            $content = unserialize(file_get_contents($this->db));
            foreach ($content as $key => $value)
            {
                if ($key != $file)
                {
                    $tmp[$key] = $value;
                }
            }
            $content = $tmp;
            $str = serialize($content);

            if ($fp = @fopen($this->db, 'wb'))
            {
                flock($fp, LOCK_EX);
                fwrite($fp, $str, strlen($str));
                flock($fp, LOCK_UN);
                fclose($fp);
            }
            else
            {
                $this->error('unable to open "' . $this->db . '" file.');
                return false;
            }
        }
        return true;
    }

    function error($str)
    {
        exit('Cache error: ' . $str);
    }

    function locate()
    {
        if ($_SERVER['REQUEST_METHOD'] == 'POST')
        {
            $str = $_SERVER['PHP_SELF'] . '_POST';
        }
        elseif (!empty($_SERVER['QUERY_STRING']))
        {
            $str = $_SERVER['PHP_SELF'] . '?' . $_SERVER['QUERY_STRING'];
        }
        else
        {
            $str = $_SERVER['PHP_SELF'];
        }

        if ($_SESSION['user_id'] != 0)
        {
            $file = $this->dir . '/' . get_template() . '/' . get_language() . '/' . $_SESSION['user_id'];
        }
        else
        {
            $file = $this->dir . '/' . get_template() . '/' . get_language();
        }

        $file .= '/' . sha1($str) . $this->ext;
        return $file;
    }

    function make_dir($dir, $mode = null)
    {
        if (is_dir($dir) || @mkdir($dir, $mode))
        {
            return true;
        }
        if (!$this->make_dir(dirname($dir), $mode))
        {
            return false;
        }
        return mkdir($dir, $mode);
    }

    function write($data, $expiration, $template)
    {
        $file = $this->locate();
        $folder = substr($file, 0, strrpos($file, '/'));

        if (!file_exists($folder))
        {
            $this->make_dir($folder, 0777);
        }

        if ($fp = @fopen($file, 'wb'))
        {
            flock($fp, LOCK_EX);
            fwrite($fp, $data, strlen($data));
            flock($fp, LOCK_UN);
            fclose($fp);
        }
        else
        {
            $this->error('unable to open "' . $file . '" file.');
            return false;
        }

        $content = unserialize(file_get_contents($this->db));
        $content[$file]['expiration'] = $expiration;
        $content[$file]['template'] = $template;
        $str = serialize($content);

        if ($fp = @fopen($this->db, 'wb'))
        {
            flock($fp, LOCK_EX);
            fwrite($fp, $str, strlen($str));
            flock($fp, LOCK_UN);
            fclose($fp);
        }
        else
        {
            $this->error('unable to open "' . $this->db . '" file.');
            return false;
        }
        return true;
    }
}

?>