<?php
// -----------------------------------------------------------------------
//
// $Id: template.php 146 2012-03-25 07:33:39Z raoul $
//
// Copyright (C) 2003-2012 Raoul Proena
// License: GNU GPL version 3 (see copying.txt file)
// Website: http://www.gnew.fr/
//
// -----------------------------------------------------------------------
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// -----------------------------------------------------------------------

class template
{
    // ---------------------------
    var $files = array();
    var $keys = array();
    var $paths = array();
    var $root = '.';
    var $values = array();
    // ---------------------------

    function error($str)
    {
        exit('Template error: ' . $str);
    }

    function parse($name, $block = '', $loop = false)
    {
        if (array_key_exists($name, $this->files))
        {
            static $expiration = 0;
            static $output = '';
            static $path = '';
            static $write = false;

            // CACHE variable ?
            if (preg_match('`{CACHE:([0-9]{1,5})(D|H|M)?}`', $this->files[$name], $matches))
            {
                if (array_key_exists(1, $matches))
                {
                    if (array_key_exists(2, $matches))
                    {
                        // Day
                        if ($matches[2] == 'D')
                        {
                            $expiration = $matches[1] * 60 * 60 * 24;
                        }
                        // Hour
                        if ($matches[2] == 'H')
                        {
                            $expiration = $matches[1] * 60 * 60;
                        }
                        // Minute
                        if ($matches[2] == 'M')
                        {
                            $expiration = $matches[1] * 60;
                        }
                    }
                    //Second
                    else
                    {
                        $expiration = $matches[1];
                    }
                }
                $path = $this->paths[$name];
                $write = true;
            }

            // Replacing variables
            $output .= preg_replace($this->keys, $this->values, $this->files[$name]);

            if ($name == 'footer')
            {
                // Removing variables with no value
                $output = preg_replace('#{[^ \n\r\t}]+}#', '', $output);

                // Sending data to write into the cache file
                if ($write)
                {
                    $date_format = get_date_format();
                    $date_offset = get_date_offset();
                    $output = str_replace($this->values['HEADER_ONLINE_USERS'], $GLOBALS['lang']['CACHE_ONLINE_USERS'], $output);
                    $output = str_replace($this->values['FOOTER_GENERATION'], sprintf($GLOBALS['lang']['CACHE_EXPIRATION'], date($date_format, (time() + $date_offset + $expiration))), $output);
                    $GLOBALS['cache']->write($output, $expiration, $path);
                }

                // Displaying the page
                echo $output;

                // Unset variables
                unset($output);
                unset($path);
                $expiration = 0;
                $write = false;

                // Unset arrays
                unset($this->files);
                unset($this->keys);
                unset($this->paths);
                unset($this->values);
            }
        }
        elseif ($loop)
        {
            if (array_key_exists($name, $this->values))
            {
                $str = preg_replace($this->keys, $this->values, $this->values[$name]);
                if (array_key_exists($block, $this->values))
                {
                    $this->set_var($block, $this->values[$block] . $str);
                }
                else
                {
                    $this->set_var($block, $str);
                }
            }
            else
            {
                $this->error('unable to parse "' . $name . '" block.');
                return false;
            }
        }
        else
        {
            $this->error('unable to parse "' . $name . '" file.');
            return false;
        }
        return true;
    }

    function set_block($parent, $name, $block)
    {
        if (array_key_exists($parent, $this->files))
        {
            $pattern = '`[ \t]*<!-- BEGIN ' . $name . ' -->\s*?\n?(\s*.*?\n?)\s*<!-- END ' . $name . ' -->\s*?\n?`s';
            if (preg_match_all($pattern, $this->files[$parent], $matches))
            {
                $this->files[$parent] = preg_replace($pattern, '{' . $block . '}', $this->files[$parent]);
                $this->set_var($name, $matches[1][0]);
            }
            else
            {
                $this->error('unable to set block.');
                return false;
            }
        }
        else
        {
            $this->error('unable to open parent file.');
            return false;
        }
        return true;
    }

    function set_file($name, $file)
    {
        if (!empty($file))
        {
            $handle = rtrim($this->root, '/') . '/' . $file;
            if ($fp = @fopen($handle, 'rb'))
            {
                if (!empty($name))
                {
                    $this->files[$name] = fread($fp, filesize($handle));
                    $this->paths[$name] = $handle;
                    fclose($fp);
                }
                else
                {
                    $this->error('function set_file(): $name argument is empty.');
                    return false;
                }
            }
            else
            {
                $this->error('unable to open "' . $handle . '" file.');
                return false;
            }
        }
        else
        {
            $this->error('function set_file(): $file argument is empty.');
            return false;
        }
        return true;
    }

    function set_var($name, $value = '')
    {
        if (!empty($name))
        {
            if (!is_array($name))
            {
                $this->keys[$name] = '`' . preg_quote('{' . $name . '}') . '`';
                $this->values[$name] = $value;
            }
            else
            {
                reset($name);
                while (list($k, $v) = each($name))
                {
                    $this->keys[$k] = '`' . preg_quote('{' . $k . '}') . '`';
                    $this->values[$k] = $v;
                }
            }
        }
        else
        {
            $this->error('function set_var(): $name argument is empty.');
            return false;
        }
        return true;
    }

    function template($root)
    {
        if (!is_dir($root))
        {
            $this->error('"' . $root . '" does not exist or is not a directory.');
            return false;
        }
        $this->root = $root;
        return true;
    }
}

?>